@@ -1052,7 +1052,7 @@ def main():
             dy.discover()
 
         if args.dyagram_args[0].lower() == "export":
-            dy = export.DiagramExport(verbose=args.verbose)
+            dy = export.DiagramExport()
             dy.export()
 
 
